@@ -5,18 +5,21 @@
 #![doc = include_str!("../Readme.md")]
 
 mod circle;
+mod ellipse;
+mod line;
 mod point;
-// mod traits;
 
 pub use float::{π, Float};
 
-/// A 2D point.
+/// The representation of a ellipse.
 #[derive(Clone, Copy, Debug, PartialEq)]
-pub struct Point {
-    /// The x-coordinate.
-    pub x: Float,
-    /// The y-coordinate.
-    pub y: Float,
+pub struct Ellipse {
+    a: Float,
+    b: Float,
+    c: Float,
+    d: Float,
+    e: Float,
+    f: Float,
 }
 
 /// A circle.
@@ -28,6 +31,24 @@ pub struct Circle {
     pub radius: Float,
 }
 
+/// A circle.
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub struct Line {
+    /// Start of the line.
+    pub start: Point,
+    /// End of the line.
+    pub end: Point,
+}
+
+/// A 2D point.
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub struct Point {
+    /// The x-coordinate.
+    pub x: Float,
+    /// The y-coordinate.
+    pub y: Float,
+}
+
 // noinspection NonAsciiCharacters
 #[cfg(feature = "f32")]
 mod float {
